class Client {
    constructor() {
        this.connected = false;
        let uri = 'ws://localhost:8082';
        this.progress = document.getElementById('progress');
        this.client = new WebSocket(uri);
        this.client.onopen = this.onOpen.bind(this);
        this.client.onmessage = this.onMessage.bind(this);
    }
    onMessage(event) {
        const msg = JSON.parse(event.data);
        if (typeof msg.state !== 'undefined' && msg.state.sequence !== null) {
            this.setSequence(msg.state.sequence);
        }
        else if (typeof msg.cmd !== 'undefined' && msg.cmd !== null) {
            this.cmd(msg);
        }
    }
    onOpen(event) {
        console.log('Connected');
        this.connected = true;
    }
    setSequence(sequence) {
        const percent = sequence.progress * 100.0;
        this.progress.value = percent;
        this.progress.innerText = `${Math.floor(percent)}%`;
    }
    cmd(msg) {
        switch (msg.cmd) {
            case 'open':
                this.receiveCameraOpen();
                break;
            case 'close':
                this.receiveCameraClose();
                break;
            case 'select':
                this.receiveSelect(msg);
                break;
            default:
                console.warn(`No command "${msg.cmd}"`);
                break;
        }
    }
    disableClass(className) {
        document.querySelectorAll(`.${className}`).forEach((el) => {
            el.disabled = true;
        });
    }
    enableClass(className) {
        document.querySelectorAll(`.${className}`).forEach((el) => {
            el.disabled = false;
        });
    }
    sendCameraOpen() {
        console.log('send camera open');
        this.disableClass('manualCtrl');
        this.client.send(JSON.stringify({ cmd: 'open' }));
    }
    receiveCameraOpen() {
        console.log('got camera open');
        this.enableClass('manualCtrl');
    }
    sendCameraClose() {
        console.log('send camera close');
        this.disableClass('manualCtrl');
        this.client.send(JSON.stringify({ cmd: 'close' }));
    }
    receiveCameraClose() {
        console.log('got camera close');
        this.enableClass('manualCtrl');
    }
    sendSelect() {
        const sequence = document.getElementById('sequence').value;
        let msg;
        if (sequence === '- Select Image Sequence -') {
            return;
        }
        msg = { cmd: 'select', sequence };
        console.log('send select');
        console.log(sequence);
        this.client.send(JSON.stringify(msg));
    }
    receiveSelect(msg) {
        console.log('got select');
        console.dir(msg);
    }
    fullscreen() {
        if (!document.fullscreenElement) {
            document.documentElement.requestFullscreen();
        }
        else {
            this.exitFullscreen();
        }
    }
    exitFullscreen() {
        if (document.fullscreenElement) {
            document.exitFullscreen();
        }
    }
}
const client = new Client();
//# sourceMappingURL=index.js.map